@@ -10,6 +10,19 @@ _atlas_label = "ATLAS"
 _hist_colors = _mpl.rcParams["axes.prop_cycle"]()
 
 
+class DimensionError(Exception):
+    "Error due to incorrect / unsupported histogram dimension"
+    def __init__(self, msg):
+        "Histogram has incorrect / unsupported dimension"
+        super().__init__(self, msg)
+
+
+class ViolatesPlottableHistogramError(Exception):
+    "Error due to histogram object violating the PlottableHistogram protocol"
+    def __init__(self, msg):
+        "Histogram violates PlottableHistogram protocol"
+        super().__init__(self, msg)
+
 class BinningMismatchError(Exception):
     "Error due to histogram binning mismatch"
 
@@ -31,15 +44,27 @@ class Background:
         -----------
         label : str
             Background label for legend
-        hist : array_like
-            Bin contents
+        hist : array_like or PlottableHistogram
+            Bin contents. If hist is a ``PlottableHistogram`` stat_errs is ignored unless it is `sqrt`.
         stat_errs : array_like
             Statistical errors on hist
-        syst_errs : array_like
+        syst_errs : array_like or PlottableHist
             Systematic errors on hist
         color : color
             Background color for histogram
         """
+        if hasattr(hist, 'axes'): # Object should meet the PlottableHistogram protocol
+            if not hasattr(hist, 'values') or not hasattr(hist, 'variances'):
+                raise ViolatesPlottableHistogramError("hist violates PlottableHistogram protocol")
+            if len(hist.axes) != 1:
+                raise DimensionError("Only 1D histograms are supported here")
+            hist_obj = hist
+            bins = hist.axes[0].edges()
+            hist = hist_obj.values()
+            if not isinstance(stat_errs, str):
+                stat_errs = none if hist_obj.variances() is None else np.sqrt(hist_obj.variances())
+        else:
+            bins = None
         if stat_errs is None:
             stat_errs = _np.zeros_like(hist)
         elif isinstance(stat_errs, str):
@@ -55,6 +80,7 @@ class Background:
             if len(hist) != len(syst_errs):
                 raise BinningMismatchError("Syst errors have incorrect binning")
 
+        self.bins = bins
         self.hist = hist
         self.stat_errs = stat_errs
         if color is None:
@@ -97,17 +123,16 @@ def plot_band(bins, low, high, ax=None, **kwargs):
     ax.fill_between(x, new_low, new_high, **kwargs)
 
 
-def plot_backgrounds(bins, backgrounds, ax=None):
+def plot_backgrounds(backgrounds, bins, ax=None):
     """
     Plot stacked backgrounds
 
     Parameters
     ----------
-
-    bins : array_like
-        Bin edges
     backgrounds : [Background]
         List of backgrounds to be plotted, in order (bottom to top)
+    bins : array_like, optional
+        Bin edges. To preserve backward compatibility, ``backgrounds`` and ``bins`` may be exchanged.
     ax : mpl.axes.Axes, optional
         Axes to draw on (defaults to current axes)
 
@@ -118,10 +143,16 @@ def plot_backgrounds(bins, backgrounds, ax=None):
     total_err : array_like
         Total error on background histogram
     """
+    if bins is not None and isinstance(bins[0], 'Background'):
+        bins, backgrounds = backgrounds, bins
     if ax is None:
         ax = _mpl.pyplot.gca()
     if len(backgrounds) < 1:
         return
+    if bins is None:
+        if backgrounds[0].bins is None:
+            raise TypeError("bins is required if backgrounds were not constructed from PlottableHists")
+        bins = backgrounds[0].bins
     if len(backgrounds[0].hist) != len(bins) - 1:
         raise BinningMismatchError("Invalid binning supplied")
     n_bkgs = len(backgrounds)
@@ -179,6 +210,8 @@ def plot_signal(label, bins, hist, stat_errs=None, syst_errs=None, color=None, a
     """
     Plot signal histogram
 
+    NB: :func:`atlas_mpl_style.uhi.plot_signal` provides a version of this function that accepts a ``PlottableHistogram``.
+
     Parameters
     ----------
     label : str
@@ -247,6 +280,8 @@ def plot_data(bins, hist, stat_errs=None, color="k", label="Data", ax=None):
     """
     Plot data
 
+    NB: :func:`atlas_mpl_style.uhi.plot_data` provides a version of this function that accepts a ``PlottableHistogram``.
+
     Parameters
     ----------
     label : str, optional
@@ -310,6 +345,8 @@ def plot_ratio(
     """
     Plot ratio plot
 
+    NB: :func:`atlas_mpl_style.uhi.plot_ratio` provides a version of this function that accepts ``PlottableHistogram``s.
+
     Parameters
     ----------
     bins : array_like
@@ -323,14 +360,14 @@ def plot_ratio(
     bkg_errs : array_like
         Total errors on total background
     ratio_ax : mpl.axes.Axes
-        Ratio axes (produced using `ampl.ratio_axes()`)
+        Ratio axes (produced using :func:`atlas_mpl_style.ratio_axes()`)
     max_ratio : float, optional
         Maximum ratio (defaults to 0.2 for "diff", 1.2 for "raw", 3 for "significances")
     plottype : {"diff", "raw", "significances"}
-        Type of ratio to plot.
-        "diff" : (data - bkg) / bkg
-        "raw" : data / bkg
-        "significances" : Significances (from `ampl.utils.significance()`)
+        | Type of ratio to plot.
+        | "diff" : (data - bkg) / bkg
+        | "raw" : data / bkg
+        | "significances" : Significances (using :func:`atlas_mpl_style.utils.significance()`)
     """
     # divide by zero is common -- ignore errors
     olderr = _np.seterr(all="ignore")
@@ -425,6 +462,8 @@ def plot_1d(label, bins, hist, stat_errs=None, color=None, ax=None, **kwargs):
     """
     Plot single 1D histogram
 
+    NB: :func:`atlas_mpl_style.uhi.plot_1d` provides a version of this function that accepts a ``PlottableHistogram``.
+
     Parameters
     ----------
     label : str
@@ -440,7 +479,7 @@ def plot_1d(label, bins, hist, stat_errs=None, color=None, ax=None, **kwargs):
     ax : mpl.axes.Axes, optional
         Axes to draw on (defaults to current axes)
     **kwargs
-        Extra parameters passed to `plt.hist`
+        Extra parameters passed to ``plt.hist``
     """
     if ax is None:
         ax = _mpl.pyplot.gca()
@@ -479,6 +518,8 @@ def plot_2d(xbins, ybins, hist, ax=None, pad=0.005, **kwargs):
     """
     Plot 2D histogram
 
+    NB: :func:`atlas_mpl_style.uhi.plot_2d` provides a version of this function that accepts a ``PlottableHistogram``.
+
     Parameters
     ----------
     xbins : array_like
@@ -492,7 +533,7 @@ def plot_2d(xbins, ybins, hist, ax=None, pad=0.005, **kwargs):
     pad : float (0. - 1.), optional
         Padding for colorbar (defaults to 0.005)
     **kwargs
-        Extra parameters passed to `pcolormesh`
+        Extra parameters passed to ``pcolormesh``
 
     Returns
     -------
